@@ -20,20 +20,20 @@
 # Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 # MA 02111-1307 USA
 
-id = "0708af8b01f64f77bb36f2100ac99d0fad69a4bc"
-date = "2020-06-24 19:55:46 +0000"
+id = "5fbcedaa62243f9a507772703393552181b99f9b"
+date = "2020-07-9 23:31:28 +0000"
 branch = "None"
-tag = "lalinference-v2.0.1"
+tag = "lalinference-v2.0.2"
 if tag == "None":
     tag = None
 author = "Adam Mercer <adam.mercer@ligo.org>"
 builder = "Adam Mercer <adam.mercer@ligo.org>"
-committer = "Adam Mercer <adam.mercer@ligo.org>"
+committer = "Adam Mercer <ramercer@gmail.com>"
 status = "CLEAN: All modifications committed"
 version = id
 verbose_msg = """Branch: None
-Tag: lalinference-v2.0.1
-Id: 0708af8b01f64f77bb36f2100ac99d0fad69a4bc
+Tag: lalinference-v2.0.2
+Id: 5fbcedaa62243f9a507772703393552181b99f9b
 
 Builder: Adam Mercer <adam.mercer@ligo.org>
 Repository status: CLEAN: All modifications committed"""
@@ -54,9 +54,9 @@ def check_match(foreign_id, onmismatch="raise"):
     """
     if onmismatch not in ("raise", "warn"):
         raise ValueError(onmismatch + " is an unrecognized value of onmismatch")
-    if foreign_id == "0708af8b01f64f77bb36f2100ac99d0fad69a4bc":
+    if foreign_id == "5fbcedaa62243f9a507772703393552181b99f9b":
         return
-    msg = "Program id (0708af8b01f64f77bb36f2100ac99d0fad69a4bc) does not match given id (%s)." % foreign_id
+    msg = "Program id (5fbcedaa62243f9a507772703393552181b99f9b) does not match given id (%s)." % foreign_id
     if onmismatch == "raise":
         raise VersionMismatchError(msg)
 
